/**
 * AWS credentials in the form of access key id and secret access key, a region and a
 * device policy name.
 */
type AWSCredentials = {
    aws: {
        access_key_id: string;
        secret_access_key: string;
        region: string;
        device_policy_name: string;
    };
};

/**
 * Shared Access Secret is an authentication mechanism in the form of a
 * connection string for Azure IoT Hub.
 */
type AzureSharedAccessSecret = {
    connection_string: string;
};

/**
 * HTTP Webhook configuration.
 */
type HTTP = {
    http: {
        /**
         * The destination URL for the webhook. The webhook will send POST requests with event details to this target URL.
         */
        url: string;
        /**
         * An optional secret used to verify the integrity of the payload. The string must be in hexadecimal format.
         */
        secret?: string;
    };
};

type Credentials = {
    /**
     * The credential type
     */
    type: Credentials.type;
} & (AWSCredentials | AzureSharedAccessSecret | HTTP);
declare namespace Credentials {
    /**
     * The credential type
     */
    enum type {
        AWS = "aws",
        SAS = "sas",
        HTTP = "http"
    }
}

type Integration = {
    /**
     * A unique integration identifier generated by the mender server
     */
    id?: string;
    provider: Integration.provider;
    credentials: Credentials;
    /**
     * A short human readable description (max 1024 characters).
     */
    description?: string;
    /**
     * An array of scopes for the integration. Currently we support deviceauth
     * and inventory scopes. The former will match the events related to a device
     * state (accepted, decomissioned), while the latter the inventory changed event.
     */
    scopes?: Array<"deviceauth" | "inventory">;
};
declare namespace Integration {
    enum provider {
        IOT_HUB = "iot-hub",
        IOT_CORE = "iot-core",
        WEBHOOK = "webhook"
    }
}

declare const auditLogsApiUrl: string;
declare const tenantadmApiUrlv1: string;
declare const tenantadmApiUrlv2: string;
declare const ssoIdpApiUrlv1: string;
declare const XML_METADATA_FORMAT = "xml";
declare const JSON_METADATA_FORMAT = "json";
declare const getSamlStartUrl: (id: any) => string;
declare const getOidcStartUrl: (id: any) => string;
declare const SSO_TYPES: {
    saml: {
        id: string;
        type: string;
        title: string;
        metadataFormat: string;
        editorLanguage: string;
        contentType: string;
        getStartUrl: (id: any) => string;
        configDetails: {
            key: string;
            label: string;
            getValue: (id: any) => string;
        }[];
    };
    oidc: {
        id: string;
        type: string;
        title: string;
        metadataFormat: string;
        editorLanguage: string;
        contentType: string;
        getStartUrl: (id: any) => string;
        configDetails: {
            key: string;
            label: string;
            getValue: (id: any) => string;
        }[];
    };
};
declare const AUDIT_LOGS_TYPES: {
    title: string;
    queryParameter: string;
    value: string;
}[];
declare const SP_AUDIT_LOGS_TYPES: {
    title: string;
    queryParameter: string;
    value: string;
}[];
interface Webhook extends Integration {
    provider: Integration.provider.WEBHOOK;
    scopes?: string[];
}
declare const emptyWebhook: Webhook;
declare const TENANT_LIST_DEFAULT: {
    page: number;
    perPage: number;
};

export { AUDIT_LOGS_TYPES, JSON_METADATA_FORMAT, SP_AUDIT_LOGS_TYPES, SSO_TYPES, TENANT_LIST_DEFAULT, type Webhook, XML_METADATA_FORMAT, auditLogsApiUrl, emptyWebhook, getOidcStartUrl, getSamlStartUrl, ssoIdpApiUrlv1, tenantadmApiUrlv1, tenantadmApiUrlv2 };
